/*
 * Copyright © 2022 DATAMART LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ru.datamart.kafka.clickhouse.reader.controller;


import io.micrometer.prometheus.PrometheusMeterRegistry;
import io.netty.handler.codec.http.HttpResponseStatus;
import io.prometheus.client.exporter.common.TextFormat;
import io.vertx.core.http.HttpHeaders;
import io.vertx.ext.web.RoutingContext;
import io.vertx.micrometer.backends.BackendRegistries;
import lombok.extern.slf4j.Slf4j;
import lombok.val;
import org.apache.commons.lang3.exception.ExceptionUtils;
import org.springframework.stereotype.Service;
import ru.datamart.kafka.clickhouse.reader.configuration.properties.PrometheusProperties;

@Slf4j
@Service
public class MicrometerController {

    private final PrometheusProperties prometheusProperties;

    public MicrometerController(PrometheusProperties prometheusProperties) {
        this.prometheusProperties = prometheusProperties;
    }

    public void getMetrics(RoutingContext routingContext) {
        if (!prometheusProperties.isEnabled()) {
            routingContext.response().setStatusCode(HttpResponseStatus.NOT_FOUND.code())
                    .end("Prometheus metrics are disabled");
            return;
        }

        try {
            val meterRegistry = BackendRegistries.getDefaultNow();
            val prometheusMeterRegistry = (PrometheusMeterRegistry) meterRegistry;
            routingContext.response()
                    .setStatusCode(HttpResponseStatus.OK.code())
                    .putHeader(HttpHeaders.CONTENT_TYPE, TextFormat.CONTENT_TYPE_004)
                    .end(prometheusMeterRegistry.scrape());
        } catch (Throwable e) {
            log.error("Failed to obtain prometheus metrics", e);
            routingContext.response()
                    .setStatusCode(HttpResponseStatus.INTERNAL_SERVER_ERROR.code())
                    .end("Failed to obtain metrics: " + ExceptionUtils.getMessage(e));
        }
    }
}
