/*
 * Copyright © 2022 DATAMART LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ru.datamart.kafka.clickhouse.writer.service.executor;

import io.vertx.core.Future;
import lombok.extern.slf4j.Slf4j;
import lombok.val;
import ru.datamart.kafka.clickhouse.writer.dao.ClickhouseDao;
import ru.datamart.kafka.clickhouse.writer.model.kafka.InsertChunk;

@Slf4j
public class ClickhouseExecutor {
    private final ClickhouseDao clickhouseDao;

    public ClickhouseExecutor(ClickhouseDao clickhouseDao) {
        this.clickhouseDao = clickhouseDao;
    }

    public Future<Integer> processChunk(InsertChunk chunk) {
        return Future.future(promise -> {
            val rows = chunk.getInsertSqlRequest().getParams();

            if (rows.isEmpty()) {
                log.info("Processed empty chunk {}", chunk.getInsertSqlRequest());
                promise.complete(0);
                return;
            }

            val insertedRowsCount = rows.size();
            log.info("Sent lines to write: [{}]", insertedRowsCount);
            clickhouseDao.insertRows(chunk.getInsertSqlRequest(), ar -> {
                if (ar.failed()) {
                    promise.fail(ar.cause());
                    return;
                }

                log.info("Sent lines to write: [{}] - COMPLETED", insertedRowsCount);
                promise.complete(insertedRowsCount);
            });
        });
    }
}
