/*
 * Copyright © 2022 DATAMART LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ru.datamart.kafka.clickhouse.writer.verticle;

import io.vertx.core.DeploymentOptions;
import io.vertx.core.Verticle;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Component;
import ru.datamart.kafka.clickhouse.writer.configuration.AppConfiguration;
import ru.datamart.kafka.clickhouse.writer.configuration.properties.VerticleProperties;
import ru.datamart.kafka.clickhouse.writer.controller.InsertDataController;
import ru.datamart.kafka.clickhouse.writer.controller.MicrometerController;
import ru.datamart.kafka.clickhouse.writer.controller.VersionController;
import ru.datamart.kafka.clickhouse.writer.verticle.handler.StopHandler;

@Component
@AllArgsConstructor
public class QueryVerticleProducer implements VerticleProducer {
    private final StopHandler stopHandler;
    private final InsertDataController insertDataController;
    private final VersionController versionController;
    private final MicrometerController micrometerController;
    private final AppConfiguration configuration;
    private final VerticleProperties verticleProperties;

    @Override
    public Verticle produce() {
        return new QueryVerticle(stopHandler, insertDataController, versionController, micrometerController, configuration);
    }

    @Override
    public DeploymentOptions deploymentOptions() {
        return new DeploymentOptions()
                .setInstances(verticleProperties.getQuery().getInstances());
    }
}
